@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2016 ircd-hybrid development team
+ *  Copyright (c) 2003-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,30 +21,22 @@
 
 /*! \file userhost.h
  * \brief A header for global user limits.
- * \version $Id: userhost.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: userhost.h 7925 2016-12-31 13:57:24Z michael $
  */
 
 #ifndef INCLUDED_userhost_h
 #define INCLUDED_userhost_h
 
-struct NameHost
-{
-  dlink_node node;  /* Point to other names on this hostname */
-  char name[USERLEN + 1];
-  unsigned int icount;  /* Number of =local= identd on this name*/
-  unsigned int gcount;  /* Global user count on this name */
-  unsigned int lcount;  /* Local user count on this name */
-};
-
 struct UserHost
 {
-  dlink_list list;  /* List of names on this hostname */
   struct UserHost *next;
-  char host[HOSTLEN + 1];
+  char host[HOSTIPLEN + 1];
+  unsigned int gcount;  /* Global user count on this addr */
+  unsigned int lcount;  /* Local user count on this addr */
 };
 
 extern void userhost_init(void);
-extern void userhost_count(const char *, const char *, unsigned int *, unsigned int *, unsigned int *);
-extern void userhost_add(const char *, const char *, int);
-extern void userhost_del(const char *, const char *, int);
+extern void userhost_count(const char *, unsigned int *, unsigned int *);
+extern void userhost_add(const char *, int);
+extern void userhost_del(const char *, int);
 #endif  /* INCLUDED_userhost_h */
